import React, { useEffect, useState } from "react";
import { Button, Space, Modal, FormInstance } from "antd";
import { Store } from "antd/lib/form/interface";
import { inject, observer } from "mobx-react";
import BTable from "@/components/b_table";
import SimpleForm from "@/components/form/simple_form";
import { columns, defaultConfig } from "./source_config";
import "./source.less";
import { base as baseHttp } from '@/service/base';

const Source = (props: Store) => {
  const { sourceStore } = props;
  const [isModalOpen, setIsModalOpen] = useState<boolean>(false);
  const formRef = React.useRef<FormInstance>(null);
  const [userId, setId] = useState<Number | null>(null);
  const [record, setRecord] = useState<any>(null);

  // 获取列表数据
  useEffect(() => {
    sourceStore.getlist();
  }, [sourceStore]);
  const gotoDetail = () => {};
  const upload = (e) => {
    console.log("upload", e.target.files);
    let param = new FormData();
    param.append("file", e.target.files[0]);
    baseHttp.upload("public/fts/upload",param)
  };
  return (
    <div className="contentBox">
      <Space direction="vertical" size="middle" style={{ display: "flex" }}>
        <Button type="default" onClick={() => setIsModalOpen(true)}>
          添加数据集
        </Button>
        <BTable
          store={sourceStore}
          scroll={{ x: "max-content" }}
          columns={columns}
          dataSource={sourceStore.list}
          deleteCallback={(id) => {
            sourceStore.deleteItem(id);
          }}
          actionCloumn={
            <>
              <Button size="small" onClick={() => gotoDetail()}>
                查看数据集
              </Button>
              <input
                type="file"
                name="文件上传"
                accept=".xlsx"
                onChange={upload}
              />
            </>
          }
          editCallback={(record) => {
            setIsModalOpen(true);
            formRef.current?.setFieldsValue(record);
            setRecord(record);
            setId(record.id);
          }}
        />

        <Modal
          title={!userId ? "添加数据集" : "编辑数据集"}
          width={800}
          open={isModalOpen}
          afterClose={() => formRef.current?.resetFields()}
          onOk={() => formRef.current?.submit()}
          okText="确定"
          cancelText="取消"
          onCancel={() => {
            setId(null);
            setRecord(null);
            setIsModalOpen(false);
          }}
        >
          <SimpleForm
            formName={"source_form"}
            formRef={formRef}
            colProps={25}
            onFinish={() => {
              sourceStore.add(formRef.current?.getFieldsValue());
              setIsModalOpen(false);
            }}
            createCallback={() => {
              formRef.current?.setFieldsValue(record);
            }}
            formDatas={defaultConfig as any}
          ></SimpleForm>
        </Modal>
      </Space>
    </div>
  );
};

export default inject("sourceStore")(observer(Source));
